'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _levels = require('./levels');

var _levels2 = _interopRequireDefault(_levels);

var _helpers = require('../helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const FORMATTERS = [{
  name: 'log',
  handler: 'log',
  level: _levels2.default.NOTICE
}, {
  name: 'info',
  output: 'stdout',
  format: _chalk2.default.blue,
  level: _levels2.default.INFO
}, {
  name: 'warn',
  output: 'stderr',
  format: _chalk2.default.cyan,
  level: _levels2.default.WARN
}, {
  name: 'error',
  output: 'stderr',
  format: _chalk2.default.red,
  level: _levels2.default.ERROR
}, {
  name: 'time',
  output: 'stdout',
  format: _chalk2.default.bold,
  aside: option => `[${ (0, _helpers.timestamp)(option) }]`,
  level: _levels2.default.NOTICE
}];

function aside(formatter, options = {}) {
  let value;

  if (options.aside !== undefined) {
    value = options.aside;
  } else if ((0, _helpers.isFunction)(formatter.aside)) {
    value = formatter.aside(options);
  } else {
    value = formatter.name;
  }

  if (value) {
    return formatter.format(value);
  }

  return false;
}

exports.default = Object.freeze(FORMATTERS.map(formatter => ({
  name: formatter.name,
  output: formatter.output,
  handler: formatter.handler,
  format: formatter.format,
  level: formatter.level,
  aside: options => aside(formatter, options)
})));
//# sourceMappingURL=formatters.js.map