'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _global = require('../global');

var _global2 = _interopRequireDefault(_global);

var _formatters = require('./formatters');

var _formatters2 = _interopRequireDefault(_formatters);

var _levels = require('./levels');

var _levels2 = _interopRequireDefault(_levels);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const INSTANCE = Symbol.for('spinr@global');

class Logger {
  constructor() {
    this.verbosity = _levels2.default.NOTICE;

    _formatters2.default.forEach(formatter => {
      this[formatter.name] = (...args) => {
        if (this.verbosity > (0, _levels.verbosity)(formatter.level)) {
          return;
        } else if (formatter.handler) {
          _global2.default[formatter.handler](...args);
          return;
        }

        const [message, options] = args;
        const aside = formatter.aside(options);
        _global2.default[formatter.output].write(`${ aside ? `${ aside } ` : '' }${ message }\n`);
      };
    });
  }

  set verbosity(name) {
    this.level = (0, _levels.verbosity)(name);
  }

  get verbosity() {
    return this.level;
  }
}

// Export as singleton

exports.default = (() => {
  let logger = global[INSTANCE];

  if (!logger) {
    logger = global[INSTANCE] = new Logger();
  }

  return logger;
})();
//# sourceMappingURL=index.js.map